```@meta
CurrentModule = Antique
```

# Hydrogen Atom

The hydrogen atom is the simplest 2-body Coulomb system.

## Definitions

``Z`` is the atomic number.

#### Schrödinger Equation
```math
  \hat{H} \psi(\pmb{r}) = E \psi(\pmb{r})
```

#### Hamiltonian
```math
  \hat{H} = - \frac{\hbar^2}{2\mu} \frac{\mathrm{d}^2}{\mathrm{d}r ^2} + V(r).
```
Where, $\mu=\left(\frac{1}{m_\mathrm{e}}+\frac{1}{m_\mathrm{p}}\right)^{-1}$ is the reduced mass of electron $\mathrm{e}$ and proton $\mathrm{p}$. $\mu = m_\mathrm{e}$ holds in the limit $m_\mathrm{p}\rightarrow\infty$. 

#### Potential
`V(r; Z=Z, a₀=a₀)`
```math
  \begin{aligned}
  V(r)
  &= - \frac{Ze^2}{4\pi\varepsilon_0 r} 
  &= - \frac{e^2}{4\pi\varepsilon_0 a_0} \frac{Z}{r/a_0}
  &= - \frac{Z}{r/a_0} E_\mathrm{h}
  \end{aligned}
```

#### Eigen Values
`E(; n=1, Z=Z, Eₕ=Eₕ)`
```math
  E_n = -\frac{m_\mathrm{e} e^4 Z^2}{2n^2(4\pi\varepsilon_0)^2\hbar^2} = -\frac{Z^2}{2n^2} E_\mathrm{h}
```
Where, ``E_\mathrm{h}`` is the Hartree energy, one of atomic unit. About atomic units, see section 3.9.2 of the [IUPAC GreenBook](https://iupac.org/what-we-do/books/greenbook/). In other units, ``E_\mathrm{h} = 27.211~386~245~988(53)~\mathrm{eV}`` from [here](https://physics.nist.gov/cgi-bin/cuu/Value?hrev).

#### Eigen Functions
`ψ(r, θ, φ; n=1, l=0, m=0, Z=Z, a₀=a₀)`
```math
  \psi_{nlm}(\pmb{r}) = R_{nl}(r) Y_{lm}(\theta,\varphi)
```

#### Radial Functions
`R(r; n=1, l=0, Z=Z, a₀=a₀)`
```math
    R_{nl}(r) = -\sqrt{\frac{(n-l-1)!}{2n(n+l)!} \left(\frac{2Z}{n a_0}\right)^3} \left(\frac{2Zr}{n a_0}\right)^l \exp \left(-\frac{Zr}{n a_0}\right) L_{n+l}^{2l+1} \left(\frac{2Zr}{n a_0}\right)
```
Where, Laguerre polynomials are defined as ``L_n(x) = \frac{1}{n!} \mathrm{e}^x \frac{\mathrm{d}^n}{\mathrm{d}x ^n} \left( \mathrm{e}^{-x} x^n \right)``, and associated Laguerre polynomials are defined as ``L_n^{k}(x) = \frac{\mathrm{d}^k}{\mathrm{d}x^k} L_n(x)``. Note that, replace ``2n(n+l)!`` with ``2n[(n+l)!]^3`` if Laguerre polynomials are defined as ``L_n(x) = \mathrm{e}^x \frac{\mathrm{d}^n}{\mathrm{d}x ^n} \left( \mathrm{e}^{-x} x^n \right)``.

#### Associated Laguerre Polynomials
`L(x; n=0, k=0)`

Rodrigues' formula & closed-form:
```math
  \begin{aligned}
  L_n^{k}(x)
    &= \frac{\mathrm{d}^k}{\mathrm{d}x^k} L_n(x) \\
    &= \frac{\mathrm{d}^k}{\mathrm{d}x^k} \frac{1}{n!} \mathrm{e}^x \frac{\mathrm{d}^n}{\mathrm{d}x ^n} \left( \mathrm{e}^{-x} x^n \right) \\
    &= \sum_{m=0}^{n-k} (-1)^{m+k} \frac{n!}{m!(m+k)!(n-m-k)!} x^m \\
    &= (-1)^k L_{n-k}^{(k)}(x)
  \end{aligned}
```

Where, Laguerre polynomials are defined as ``L_n(x)=\frac{1}{n!}\mathrm{e}^x \frac{\mathrm{d}^n}{\mathrm{d}x ^n} \left( \mathrm{e}^{-x} x^n \right)``.

Examples:
```math
  \begin{aligned}
    L_0^0(x) &= 1, \\
    L_1^0(x) &= 1 - x, \\
    L_1^1(x) &= 1, \\
    L_2^0(x) &= 1 - 2 x + 1/2 x^2, \\
    L_2^1(x) &= 2 - x, \\
    L_2^2(x) &= 1, \\
    L_3^0(x) &= 1 - 3 x + 3/2 x^2 - 1/6 x^3, \\
    L_3^1(x) &= 3 - 3 x + 1/2 x^2, \\
    L_3^2(x) &= 3 - x, \\
    L_3^3(x) &= 1, \\
    L_4^0(x) &= 1 - 4 x + 3 x^2 - 2/3 x^3 + 5/12 x^4, \\
    L_4^1(x) &= 4 - 6 x + 2 x^2 - 1/6 x^3, \\
    L_4^2(x) &= 6 - 4 x + 1/2 x^2, \\
    L_4^3(x) &= 4 - x, \\
    L_4^4(x) &= 1, \\
    \vdots.
  \end{aligned}
```

#### Spherical Harmonics
`Y(θ, φ; l=0, m=0)`
```math
    Y_{lm}(\theta,\varphi) = (-1)^{\frac{|m|+m}{2}} \sqrt{\frac{2l+1}{4\pi} \frac{(l-|m|)!}{(l+|m|)!}} P_l^{|m|} (\cos\theta) \mathrm{e}^{im\varphi}
```
Note that some variants are connected by 
```math
i^{|m|+m} \sqrt{\frac{(l-|m|)!}{(l+|m|)!}} P_l^{|m|} = (-1)^{\frac{|m|+m}{2}} \sqrt{\frac{(l-|m|)!}{(l+|m|)!}} P_l^{|m|} = (-1)^m \sqrt{\frac{(l-m)!}{(l+m)!}} P_l^{m}.
```

#### Associated Legendre Polynomials
`P(x; n=0, m=0)`

Rodrigues' formula & closed-form:
```math
  \begin{aligned}
    P_n^m(x)
    &= \left( 1-x^2 \right)^{m/2} \frac{\mathrm{d}^m}{\mathrm{d}x^m} P_n(x) \\
    &= \left( 1-x^2 \right)^{m/2} \frac{\mathrm{d}^m}{\mathrm{d}x^m} \frac{1}{2^n n!} \frac{\mathrm{d}^n}{\mathrm{d}x ^n} \left[ \left( x^2-1 \right)^n \right] \\
    &= \frac{1}{2^n} (1-x^2)^{m/2} \sum_{j=0}^{\left\lfloor\frac{n-m}{2}\right\rfloor} (-1)^j \frac{(2n-2j)!}{j! (n-j)! (n-2j-m)!} x^{(n-2j-m)}.
  \end{aligned}
```

Where, Legendre polynomials are defined as ``P_n(x) = \frac{1}{2^n n!} \frac{\mathrm{d}^n}{\mathrm{d}x ^n} \left[ \left( x^2-1 \right)^n \right]``. Note that ``P_l^{-m} = (-1)^m \frac{(l-m)!}{(l+m)!} P_l^m`` for ``m<0``. (It is not compatible with ``P_k^m(t) = (-1)^m\left( 1-t^2 \right)^{m/2} \frac{\mathrm{d}^m P_k(t)}{\mathrm{d}t^m}`` caused by ``(-1)^m``.) The specific formulae are given below.

Examples:
```math
  \begin{aligned}
    P_{0}^{0}(x) &= 1, \\
    P_{1}^{0}(x) &= x, \\
    P_{1}^{1}(x) &= \left(+1\right)\sqrt{1-x^2}, \\
    P_{2}^{0}(x) &= -1/2 + 3/2 x^{2}, \\
    P_{2}^{1}(x) &= \left(-3 x\right)\sqrt{1-x^2}, \\
    P_{2}^{2}(x) &= 3 - 6 x, \\
    P_{3}^{0}(x) &= -3/2 x + 5/2 x^{3}, \\
    P_{3}^{1}(x) &= \left(3/2 - 15/2 x^{2}\right)\sqrt{1-x^2}, \\
    P_{3}^{2}(x) &= 15 x - 30 x^{2}, \\
    P_{3}^{3}(x) &= \left(15 - 30 x\right)\sqrt{1-x^2}, \\
    P_{4}^{0}(x) &= 3/8 - 15/4 x^{2} + 35/8 x^{4}, \\
    P_{4}^{1}(x) &= \left(- 15/2 x + 35/2 x^{3}\right)\sqrt{1-x^2}, \\
    P_{4}^{2}(x) &= -15/2 + 15 x + 105/2 x^{2} - 105 x^{3}, \\
    P_{4}^{3}(x) &= \left(105 x - 210 x^{2}\right)\sqrt{1-x^2}, \\
    P_{4}^{4}(x) &= 105 - 420 x + 420 x^{2}, \\
    & \vdots.
  \end{aligned}
```

#### References
- cpprefjp, [legendre](https://cpprefjp.github.io/reference/cmath/legendre.html), [assoc_legendre](https://cpprefjp.github.io/reference/cmath/assoc_legendre.html), [laguerre](https://cpprefjp.github.io/reference/cmath/laguerre.html), [assoc_laguerre](https://cpprefjp.github.io/reference/cmath/assoc_laguerre.html)
- The Digital Library of Mathematical Functions (DLMF), [18.3 Table1](https://dlmf.nist.gov/18.3#T1), [18.5 Table1](https://dlmf.nist.gov/18.5#T1), [18.5.16](https://dlmf.nist.gov/18.5#E16), [18.3 Table1](https://dlmf.nist.gov/18.3#T1), [18.5 Table1](https://dlmf.nist.gov/18.5#T1), [18.5.17](https://dlmf.nist.gov/18.5#E17), [18.3 Table1](https://dlmf.nist.gov/18.3#T1), [18.5 Table1](https://dlmf.nist.gov/18.5#T1), [18.5.12](https://dlmf.nist.gov/18.5#E12)
- L. D. Landau, E. M. Lifshitz, Quantum Mechanics (Pergamon Press, 1965), [p.598 (c.1)](https://archive.org/details/ost-physics-landaulifshitz-quantummechanics/page/n611/mode/2up), [p.598 (c.4)](https://archive.org/details/ost-physics-landaulifshitz-quantummechanics/page/n611/mode/2up), [p.603 (d.13)](https://archive.org/details/ost-physics-landaulifshitz-quantummechanics/page/n615/mode/2up), [p.603 (d.13)](https://archive.org/details/ost-physics-landaulifshitz-quantummechanics/page/n615/mode/2up)
- L. I. Schiff, Quantum Mechanics (McGraw-Hill Book Company, 1968), [p.79 (14.12)](https://archive.org/details/ost-physics-schiff-quantummechanics/page/n95/mode/1up), [p.93 (16.19)](https://archive.org/details/ost-physics-schiff-quantummechanics/page/n109/mode/1up)
- A. Messiah, Quanfum Mechanics (Dover Publications, 1999), [p.493 (B.72)](https://archive.org/details/quantummechanics0000mess/page/491/mode/1up), [p.494 Table](https://archive.org/details/quantummechanics0000mess/page/494/mode/1up), [p.493 (B.72)](https://archive.org/details/quantummechanics0000mess/page/491/mode/1up), [p.483 (B.12)](https://archive.org/details/quantummechanics0000mess/page/483/mode/1up), [p.483 (B.12)](https://archive.org/details/quantummechanics0000mess/page/483/mode/1up)
- W. Greiner, Quantum Mechanics: An Introduction Third Edition (Springer, 1994), [p.83 (4)](https://archive.org/details/quantummechanics0001grei_u4x0/page/83/mode/1up), [p.83 (5)](https://archive.org/details/quantummechanics0001grei_u4x0/page/83/mode/1up), [p.149 (21)](https://archive.org/details/quantummechanics0001grei_u4x0/page/149/mode/1up)
- D. J. Griffiths, Introduction to Quantum Mechanics (Prentice Hall, 1995), [p.126 (4.28)](https://archive.org/details/griffiths-introduction-to-quantum-mechanics/page/126/mode/1up), [p.96 Table3.1](https://archive.org/details/griffiths-introduction-to-quantum-mechanics/page/95/mode/1up), [p.126 (4.27)](https://archive.org/details/griffiths-introduction-to-quantum-mechanics/page/126/mode/1up), [p.139 (4.88)](https://archive.org/details/griffiths-introduction-to-quantum-mechanics/page/139/mode/1up), [p.140 Table4.4](https://archive.org/details/griffiths-introduction-to-quantum-mechanics/page/140/mode/1up), [p.139 (4.87)](https://archive.org/details/griffiths-introduction-to-quantum-mechanics/page/139/mode/1up), [p.140 Table4.5](https://archive.org/details/griffiths-introduction-to-quantum-mechanics/page/140/mode/1up)
- D. A. McQuarrie, J. D. Simon, Physical Chemistry: A Molecular Approach (University Science Books, 1997), [p.195 Table6.1](https://archive.org/details/McQuarrieSimonPhysicalChemistrySolutions/McQuarrie_Simon_Physical_Chemistry1997/page/n218/mode/1up), [p.196 (6.26)](https://archive.org/details/McQuarrieSimonPhysicalChemistrySolutions/McQuarrie_Simon_Physical_Chemistry1997/page/n219/mode/1up), [p.196 Table6.2](https://archive.org/details/McQuarrieSimonPhysicalChemistrySolutions/McQuarrie_Simon_Physical_Chemistry1997/page/n220/mode/1up), [p.207 Table6.4](https://archive.org/details/McQuarrieSimonPhysicalChemistrySolutions/McQuarrie_Simon_Physical_Chemistry1997/page/n230/mode/1up)
- P. W. Atkins, J. De Paula, Atkins' Physical Chemistry, 8th edition (W. H. Freeman, 2008), [p.234](https://archive.org/details/atkinsphysicalch00pwat/page/324/mode/2up?q=Laguerre)
- [J. J. Sakurai, J. Napolitano, Modern Quantum Mechanics Third Edition (Cambridge University Press, 2021)](https://doi.org/10.1017/9781108587280), p.245 Problem 3.30.b, 

## Usage & Examples

[Install Antique.jl](@ref Install) for the first run and run `using Antique` before each use. The function `antique(model, parameters...)` returns a module that has `E()`, `ψ(r)`, `V(r)` and some other functions. In this system, the model name is specified by `:HydrogenAtom` and several parameters `Z`, `Eₕ`, `mₑ`, `a₀` and `ℏ` are set as optional arguments.

```julia
using Antique
H = antique(:HydrogenAtom, Z=1, Eₕ=1.0, a₀=1.0, mₑ=1.0, ℏ=1.0)
```




Parameters:

```julia
julia> H.Z
1

julia> H.Eₕ
1.0

julia> H.mₑ
1.0

julia> H.a₀
1.0

julia> H.ℏ
1.0
```



Eigen values:

```julia
julia> H.E(n=1)
-0.5

julia> H.E(n=2)
-0.125
```



Wave length ($n=2\rightarrow1$, the first line of the Lyman series):

```julia
Eₕ2nm⁻¹ = 2.1947463136320e-2 # https://physics.nist.gov/cgi-bin/cuu/CCValue?hrminv
println("ΔE = ", H.E(n=2) - H.E(n=1), " Eₕ")
println("λ  = ", ((H.E(n=2)-H.E(n=1))*Eₕ2nm⁻¹)^-1, " nm")
```

```
ΔE = 0.375 Eₕ
λ  = 121.50227341098497 nm
```





Hyperfine Splitting:

```julia
# constants: https://doi.org/10.1103/RevModPhys.93.025010
e  = 1.602176634e-19    # C      https://physics.nist.gov/cgi-bin/cuu/Value?e
h  = 6.62607015e-34     # J Hz-1 https://physics.nist.gov/cgi-bin/cuu/Value?h
c  = 299792458          # m s-1  https://physics.nist.gov/cgi-bin/cuu/Value?c
a0 = 5.29177210903e-11  # m      https://physics.nist.gov/cgi-bin/cuu/Value?bohrrada0
µ0 = 1.25663706212e-6   # N A-2  https://physics.nist.gov/cgi-bin/cuu/Value?mu0
µB = 9.2740100783e-24   # J T-1  https://physics.nist.gov/cgi-bin/cuu/Value?mub
µN = 5.0507837461e-27   # J T-1  https://physics.nist.gov/cgi-bin/cuu/Value?mun
ge = 2.00231930436256   #        https://physics.nist.gov/cgi-bin/cuu/Value?gem
gp = 5.5856946893       #        https://physics.nist.gov/cgi-bin/cuu/Value?gp

# calculation: https://doi.org/10.1119/1.12733
δ = abs(H.ψ(0,0,0))^2
ΔE = 2 / 3 * µ0 * µN * µB * gp * ge * δ * a0^(-3)
println("1/π    = ", 1/π)
println("<δ(r)> = ", δ, " a₀⁻³")
println("<δ(r)> = ", δ * a0^(-3), " m⁻³")
println("ΔE = ", ΔE, " J")
println("ν = ΔE/h = ", ΔE / h * 1e-6, " MHz")
println("λ = hc/ΔE = ", h*c/ΔE*100, " cm")
```

```
1/π    = 0.3183098861837907
<δ(r)> = 0.3183098861837908 a₀⁻³
<δ(r)> = 2.1480615849063944e30 m⁻³
ΔE = 9.427622831641132e-25 J
ν = ΔE/h = 1422.8075794882932 MHz
λ = hc/ΔE = 21.070485027063118 cm
```





Potential energy curve:

```julia
using Plots
plot(xlims=(0.0,15.0), ylims=(-0.6,0.05), xlabel="\$r~/~a_0\$", ylabel="\$V(r)/E_\\mathrm{h},~E_n/E_\\mathrm{h}\$", legend=:bottomright, size=(480,400))
plot!(0.1:0.01:15, r -> H.V(r), lc=:black, lw=2, label="") # potential
```

![](./assets/fig//HydrogenAtom_6_1.png)



Potential energy curve, Energy levels:

```julia
using Plots
plot(xlims=(0.0,15.0), ylims=(-0.6,0.05), xlabel="\$r~/~a_0\$", ylabel="\$V(r)/E_\\mathrm{h}\$", legend=:bottomright, size=(480,400))
for n in 0:10
  plot!(0.0:0.01:15, r -> H.E(n=n) > H.V(r) ? H.E(n=n) : NaN, lc=n, lw=1, label="") # energy level
end
plot!(0.1:0.01:15, r -> H.V(r), lc=:black, lw=2, label="") # potential
```

![](./assets/fig//HydrogenAtom_7_1.png)



Radial functions:

```julia
using Plots
plot(xlabel="\$r~/~a_0\$", ylabel="\$r^2|R_{nl}(r)|^2~/~a_0^{-1}\$", ylims=(-0.01,0.55), xticks=0:1:20, size=(480,400), dpi=300)
for n in 1:3
  for l in 0:n-1
    plot!(0:0.01:20, r->r^2*H.R(r,n=n,l=l)^2, lc=n, lw=2, ls=[:solid,:dash,:dot,:dashdot,:dashdotdot][l+1], label="\$n = $n, l=$l\$")
  end
end
plot!()
```

![](./assets/fig//HydrogenAtom_8_1.png)



## Testing

Unit testing and Integration testing were done using computer algebra system ([Symbolics.jl](https://symbolics.juliasymbolics.org/stable/)) and numerical integration ([QuadGK.jl](https://juliamath.github.io/QuadGK.jl/stable/)). The test script is [here](https://github.com/ohno/Antique.jl/blob/main/test/HydrogenAtom.jl).

#### Associated Legendre Polynomials $P_n^m(x)$

```math
  \begin{aligned}
    P_n^m(x)
    &= \left( 1-x^2 \right)^{m/2} \frac{\mathrm{d}^m}{\mathrm{d}x^m} P_n(x) \\
    &= \left( 1-x^2 \right)^{m/2} \frac{\mathrm{d}^m}{\mathrm{d}x^m} \frac{1}{2^n n!} \frac{\mathrm{d}^n}{\mathrm{d}x ^n} \left[ \left( x^2-1 \right)^n \right] \\
    &= \frac{1}{2^n} (1-x^2)^{m/2} \sum_{j=0}^{\left\lfloor\frac{n-m}{2}\right\rfloor} (-1)^j \frac{(2n-2j)!}{j! (n-j)! (n-2j-m)!} x^{(n-2j-m)}.
  \end{aligned}
```

``n=0, m=0:`` ✔
```math
\begin{aligned}
  P_{0}^{0}(x)
    = 1
  &= 1 \\
  &= 1
\end{aligned}
```

``n=1, m=0:`` ✔
```math
\begin{aligned}
  P_{1}^{0}(x)
    = \frac{1}{2} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)
  &= x \\
  &= x
\end{aligned}
```

``n=1, m=1:`` ✔
```math
\begin{aligned}
  P_{1}^{1}(x)
    = \left( 1 - x^{2} \right)^{\frac{1}{2}} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{2} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)
  &= \left( 1 - x^{2} \right)^{\frac{1}{2}} \\
  &= \left( 1 - x^{2} \right)^{\frac{1}{2}}
\end{aligned}
```

``n=2, m=0:`` ✔
```math
\begin{aligned}
  P_{2}^{0}(x)
    = \frac{1}{8} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)^{2}
  &= \frac{-1}{2} + \frac{3}{2} x^{2} \\
  &= \frac{-1}{2} + \frac{3}{2} x^{2}
\end{aligned}
```

``n=2, m=1:`` ✔
```math
\begin{aligned}
  P_{2}^{1}(x)
    = \left( 1 - x^{2} \right)^{\frac{1}{2}} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{8} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)^{2}
  &= 3 \left( 1 - x^{2} \right)^{\frac{1}{2}} x \\
  &= 3 \left( 1 - x^{2} \right)^{\frac{1}{2}} x
\end{aligned}
```

``n=2, m=2:`` ✔
```math
\begin{aligned}
  P_{2}^{2}(x)
    = \left( 1 - x^{2} \right) \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{8} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)^{2}
  &= 3 - 3 x^{2} \\
  &= 3 - 3 x^{2}
\end{aligned}
```

``n=3, m=0:`` ✔
```math
\begin{aligned}
  P_{3}^{0}(x)
    = \frac{1}{48} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)^{3}
  &=  - \frac{3}{2} x + \frac{5}{2} x^{3} \\
  &=  - \frac{3}{2} x + \frac{5}{2} x^{3}
\end{aligned}
```

``n=3, m=1:`` ✔
```math
\begin{aligned}
  P_{3}^{1}(x)
    = \left( 1 - x^{2} \right)^{\frac{1}{2}} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{48} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)^{3}
  &=  - \frac{3}{2} \left( 1 - x^{2} \right)^{\frac{1}{2}} + \frac{15}{2} \left( 1 - x^{2} \right)^{\frac{1}{2}} x^{2} \\
  &=  - \frac{3}{2} \left( 1 - x^{2} \right)^{\frac{1}{2}} + \frac{15}{2} \left( 1 - x^{2} \right)^{\frac{1}{2}} x^{2}
\end{aligned}
```

``n=3, m=2:`` ✔
```math
\begin{aligned}
  P_{3}^{2}(x)
    = \left( 1 - x^{2} \right) \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{48} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)^{3}
  &= 15 x - 15 x^{3} \\
  &= 15 x - 15 x^{3}
\end{aligned}
```

``n=3, m=3:`` ✔
```math
\begin{aligned}
  P_{3}^{3}(x)
    = \left( 1 - x^{2} \right)^{\frac{3}{2}} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{48} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)^{3}
  &= 15 \left( 1 - x^{2} \right)^{\frac{3}{2}} \\
  &= 15 \left( 1 - x^{2} \right)^{\frac{3}{2}}
\end{aligned}
```

``n=4, m=0:`` ✔
```math
\begin{aligned}
  P_{4}^{0}(x)
    = \frac{1}{384} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)^{4}
  &= \frac{3}{8} - \frac{15}{4} x^{2} + \frac{35}{8} x^{4} \\
  &= \frac{3}{8} - \frac{15}{4} x^{2} + \frac{35}{8} x^{4}
\end{aligned}
```

``n=4, m=1:`` ✔
```math
\begin{aligned}
  P_{4}^{1}(x)
    = \left( 1 - x^{2} \right)^{\frac{1}{2}} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{384} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)^{4}
  &=  - \frac{15}{2} \left( 1 - x^{2} \right)^{\frac{1}{2}} x + \frac{35}{2} \left( 1 - x^{2} \right)^{\frac{1}{2}} x^{3} \\
  &=  - \frac{15}{2} \left( 1 - x^{2} \right)^{\frac{1}{2}} x + \frac{35}{2} \left( 1 - x^{2} \right)^{\frac{1}{2}} x^{3}
\end{aligned}
```

``n=4, m=2:`` ✔
```math
\begin{aligned}
  P_{4}^{2}(x)
    = \left( 1 - x^{2} \right) \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{384} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)^{4}
  &= \frac{-15}{2} + 60 x^{2} - \frac{105}{2} x^{4} \\
  &= \frac{-15}{2} + 60 x^{2} - \frac{105}{2} x^{4}
\end{aligned}
```

``n=4, m=3:`` ✔
```math
\begin{aligned}
  P_{4}^{3}(x)
    = \left( 1 - x^{2} \right)^{\frac{3}{2}} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{384} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)^{4}
  &= 105 \left( 1 - x^{2} \right)^{\frac{3}{2}} x \\
  &= 105 \left( 1 - x^{2} \right)^{\frac{3}{2}} x
\end{aligned}
```

``n=4, m=4:`` ✔
```math
\begin{aligned}
  P_{4}^{4}(x)
    = \left( 1 - x^{2} \right)^{2} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{384} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \left( -1 + x^{2} \right)^{4}
  &= 105 \left( 1 - x^{2} \right)^{2} \\
  &= 105 \left( 1 - x^{2} \right)^{2}
\end{aligned}
```

```
Test Summary:                                                   | Pass  Total  Time
Pₙᵐ(x) = √(1-x²)ᵐ dᵐ/dxᵐ Pₙ(x); Pₙ(x) = 1/(2ⁿn!) dⁿ/dxⁿ (x²-1)ⁿ |   15     15  1.2s
```

#### Normalization & Orthogonality of $P_n^m(x)$

```math
\int_{-1}^{1} P_i^m(x) P_j^m(x) \mathrm{d}x = \frac{2(j+m)!}{(2j+1)(j-m)!} \delta_{ij}
```
```
  m	  i	  j	numerical         	analytical        	|error|
  0	  0	  0	2.0000000000000000	2.0000000000000000	0.0000000000000000%	✔
  0	  0	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  0	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  0	  3	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  0	  4	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  0	  5	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  0	  6	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  0	  7	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  0	  8	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  0	  9	-0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  0	  1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  1	  1	0.6666666666666666	0.6666666666666666	0.0000000000000000%	✔
  0	  1	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  1	  3	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  1	  4	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  1	  5	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  1	  6	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  1	  7	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  0	  1	  8	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  1	  9	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  2	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  2	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  2	  2	0.3999999999999999	0.4000000000000000	0.0000000000000278%	✔
  0	  2	  3	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  2	  4	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  2	  5	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  2	  6	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  2	  7	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  2	  8	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  2	  9	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  3	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  3	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  3	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  3	  3	0.2857142857142856	0.2857142857142857	0.0000000000000194%	✔
  0	  3	  4	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  3	  5	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  0	  3	  6	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  3	  7	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  3	  8	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  3	  9	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  4	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  4	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  4	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  4	  3	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  4	  4	0.2222222222222220	0.2222222222222222	0.0000000000000874%	✔
  0	  4	  5	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  4	  6	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  4	  7	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  4	  8	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  4	  9	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  5	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  5	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  5	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  5	  3	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  0	  5	  4	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  5	  5	0.1818181818181817	0.1818181818181818	0.0000000000000763%	✔
  0	  5	  6	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  5	  7	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  5	  8	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  5	  9	-0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  0	  6	  0	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  6	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  6	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  6	  3	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  6	  4	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  6	  5	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  6	  6	0.1538461538461535	0.1538461538461539	0.0000000000002165%	✔
  0	  6	  7	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  6	  8	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  6	  9	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  7	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  7	  1	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  0	  7	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  7	  3	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  7	  4	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  7	  5	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  7	  6	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  7	  7	0.1333333333333336	0.1333333333333333	0.0000000000002290%	✔
  0	  7	  8	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  7	  9	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  8	  0	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  8	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  8	  2	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  8	  3	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  8	  4	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  8	  5	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  8	  6	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  8	  7	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  8	  8	0.1176470588235297	0.1176470588235294	0.0000000000002241%	✔
  0	  8	  9	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  9	  0	-0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  0	  9	  1	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  9	  2	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  9	  3	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  9	  4	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  9	  5	-0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  0	  9	  6	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  9	  7	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  9	  8	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  9	  9	0.1052631578947375	0.1052631578947369	0.0000000000006592%	✔
  1	  1	  1	1.3333333333333335	1.3333333333333333	0.0000000000000167%	✔
  1	  1	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  1	  3	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  1	  4	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1	  1	  5	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  1	  6	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1	  1	  7	0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  1	  1	  8	0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  1	  1	  9	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  2	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  2	  2	2.4000000000000004	2.3999999999999999	0.0000000000000185%	✔
  1	  2	  3	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  2	  4	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  2	  5	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1	  2	  6	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1	  2	  7	0.0000000000000009	0.0000000000000000	0.0000000000000000%	✔
  1	  2	  8	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  2	  9	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  3	3.4285714285714293	3.4285714285714284	0.0000000000000259%	✔
  1	  3	  4	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  5	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  6	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  7	0.0000000000000013	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  8	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  9	-0.0000000000000008	0.0000000000000000	0.0000000000000000%	✔
  1	  4	  1	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1	  4	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  4	  3	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1	  4	  4	4.4444444444444455	4.4444444444444446	0.0000000000000200%	✔
  1	  4	  5	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  4	  6	0.0000000000000007	0.0000000000000000	0.0000000000000000%	✔
  1	  4	  7	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  4	  8	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  4	  9	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  5	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  5	  2	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1	  5	  3	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  5	  4	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  5	  5	5.4545454545454550	5.4545454545454541	0.0000000000000163%	✔
  1	  5	  6	0.0000000000000004	0.0000000000000000	0.0000000000000000%	✔
  1	  5	  7	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1	  5	  8	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  5	  9	-0.0000000000000042	0.0000000000000000	0.0000000000000000%	✔
  1	  6	  1	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1	  6	  2	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1	  6	  3	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  6	  4	0.0000000000000007	0.0000000000000000	0.0000000000000000%	✔
  1	  6	  5	0.0000000000000004	0.0000000000000000	0.0000000000000000%	✔
  1	  6	  6	6.4615384615384563	6.4615384615384617	0.0000000000000825%	✔
  1	  6	  7	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  6	  8	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  6	  9	0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  1	  7	  1	0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  1	  7	  2	0.0000000000000009	0.0000000000000000	0.0000000000000000%	✔
  1	  7	  3	0.0000000000000013	0.0000000000000000	0.0000000000000000%	✔
  1	  7	  4	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  7	  5	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1	  7	  6	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  7	  7	7.4666666666666739	7.4666666666666668	0.0000000000000952%	✔
  1	  7	  8	0.0000000000000013	0.0000000000000000	0.0000000000000000%	✔
  1	  7	  9	0.0000000000000006	0.0000000000000000	0.0000000000000000%	✔
  1	  8	  1	0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  1	  8	  2	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  8	  3	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  8	  4	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  8	  5	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  8	  6	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  8	  7	0.0000000000000013	0.0000000000000000	0.0000000000000000%	✔
  1	  8	  8	8.4705882352941284	8.4705882352941178	0.0000000000001258%	✔
  1	  8	  9	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  9	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  9	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  9	  3	-0.0000000000000008	0.0000000000000000	0.0000000000000000%	✔
  1	  9	  4	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  9	  5	-0.0000000000000042	0.0000000000000000	0.0000000000000000%	✔
  1	  9	  6	0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  1	  9	  7	0.0000000000000006	0.0000000000000000	0.0000000000000000%	✔
  1	  9	  8	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  9	  9	9.4736842105262831	9.4736842105263168	0.0000000000003563%	✔
  2	  2	  2	9.5999999999999996	9.5999999999999996	0.0000000000000000%	✔
  2	  2	  3	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  4	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  5	0.0000000000000004	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  6	-0.0000000000000004	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  7	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  8	0.0000000000000067	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  9	0.0000000000000006	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  3	34.2857142857142918	34.2857142857142847	0.0000000000000207%	✔
  2	  3	  4	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  5	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  6	0.0000000000000021	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  7	-0.0000000000000036	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  8	0.0000000000000020	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  9	-0.0000000000000231	0.0000000000000000	0.0000000000000000%	✔
  2	  4	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  4	  3	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  4	  4	80.0000000000000000	80.0000000000000000	0.0000000000000000%	✔
  2	  4	  5	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2	  4	  6	-0.0000000000000142	0.0000000000000000	0.0000000000000000%	✔
  2	  4	  7	-0.0000000000000009	0.0000000000000000	0.0000000000000000%	✔
  2	  4	  8	0.0000000000000155	0.0000000000000000	0.0000000000000000%	✔
  2	  4	  9	-0.0000000000000240	0.0000000000000000	0.0000000000000000%	✔
  2	  5	  2	0.0000000000000004	0.0000000000000000	0.0000000000000000%	✔
  2	  5	  3	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  5	  4	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2	  5	  5	152.7272727272727479	152.7272727272727195	0.0000000000000186%	✔
  2	  5	  6	-0.0000000000000071	0.0000000000000000	0.0000000000000000%	✔
  2	  5	  7	-0.0000000000000082	0.0000000000000000	0.0000000000000000%	✔
  2	  5	  8	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  5	  9	-0.0000000000001155	0.0000000000000000	0.0000000000000000%	✔
  2	  6	  2	-0.0000000000000004	0.0000000000000000	0.0000000000000000%	✔
  2	  6	  3	0.0000000000000021	0.0000000000000000	0.0000000000000000%	✔
  2	  6	  4	-0.0000000000000142	0.0000000000000000	0.0000000000000000%	✔
  2	  6	  5	-0.0000000000000071	0.0000000000000000	0.0000000000000000%	✔
  2	  6	  6	258.4615384615384528	258.4615384615384528	0.0000000000000000%	✔
  2	  6	  7	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  6	  8	0.0000000000000515	0.0000000000000000	0.0000000000000000%	✔
  2	  6	  9	-0.0000000000000919	0.0000000000000000	0.0000000000000000%	✔
  2	  7	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  7	  3	-0.0000000000000036	0.0000000000000000	0.0000000000000000%	✔
  2	  7	  4	-0.0000000000000009	0.0000000000000000	0.0000000000000000%	✔
  2	  7	  5	-0.0000000000000082	0.0000000000000000	0.0000000000000000%	✔
  2	  7	  6	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  7	  7	403.1999999999999318	403.1999999999999886	0.0000000000000141%	✔
  2	  7	  8	-0.0000000000000568	0.0000000000000000	0.0000000000000000%	✔
  2	  7	  9	-0.0000000000000049	0.0000000000000000	0.0000000000000000%	✔
  2	  8	  2	0.0000000000000067	0.0000000000000000	0.0000000000000000%	✔
  2	  8	  3	0.0000000000000020	0.0000000000000000	0.0000000000000000%	✔
  2	  8	  4	0.0000000000000155	0.0000000000000000	0.0000000000000000%	✔
  2	  8	  5	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  8	  6	0.0000000000000515	0.0000000000000000	0.0000000000000000%	✔
  2	  8	  7	-0.0000000000000568	0.0000000000000000	0.0000000000000000%	✔
  2	  8	  8	592.9411764705882888	592.9411764705882888	0.0000000000000000%	✔
  2	  8	  9	0.0000000000000142	0.0000000000000000	0.0000000000000000%	✔
  2	  9	  2	0.0000000000000006	0.0000000000000000	0.0000000000000000%	✔
  2	  9	  3	-0.0000000000000231	0.0000000000000000	0.0000000000000000%	✔
  2	  9	  4	-0.0000000000000240	0.0000000000000000	0.0000000000000000%	✔
  2	  9	  5	-0.0000000000001155	0.0000000000000000	0.0000000000000000%	✔
  2	  9	  6	-0.0000000000000919	0.0000000000000000	0.0000000000000000%	✔
  2	  9	  7	-0.0000000000000049	0.0000000000000000	0.0000000000000000%	✔
  2	  9	  8	0.0000000000000142	0.0000000000000000	0.0000000000000000%	✔
  2	  9	  9	833.6842105263162921	833.6842105263158373	0.0000000000000545%	✔
  3	  3	  3	205.7142857142857224	205.7142857142857224	0.0000000000000000%	✔
  3	  3	  4	-0.0000000000000284	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  5	-0.0000000000000144	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  6	0.0000000000000286	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  7	-0.0000000000000355	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  8	0.0000000000000639	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  9	0.0000000000000151	0.0000000000000000	0.0000000000000000%	✔
  3	  4	  3	-0.0000000000000284	0.0000000000000000	0.0000000000000000%	✔
  3	  4	  4	1120.0000000000000000	1120.0000000000000000	0.0000000000000000%	✔
  3	  4	  5	0.0000000000000004	0.0000000000000000	0.0000000000000000%	✔
  3	  4	  6	0.0000000000000897	0.0000000000000000	0.0000000000000000%	✔
  3	  4	  7	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  4	  8	-0.0000000000001990	0.0000000000000000	0.0000000000000000%	✔
  3	  4	  9	-0.0000000000001137	0.0000000000000000	0.0000000000000000%	✔
  3	  5	  3	-0.0000000000000144	0.0000000000000000	0.0000000000000000%	✔
  3	  5	  4	0.0000000000000004	0.0000000000000000	0.0000000000000000%	✔
  3	  5	  5	3665.4545454545450411	3665.4545454545454959	0.0000000000000124%	✔
  3	  5	  6	0.0000000000004547	0.0000000000000000	0.0000000000000000%	✔
  3	  5	  7	-0.0000000000000284	0.0000000000000000	0.0000000000000000%	✔
  3	  5	  8	-0.0000000000001492	0.0000000000000000	0.0000000000000000%	✔
  3	  5	  9	-0.0000000000000568	0.0000000000000000	0.0000000000000000%	✔
  3	  6	  3	0.0000000000000286	0.0000000000000000	0.0000000000000000%	✔
  3	  6	  4	0.0000000000000897	0.0000000000000000	0.0000000000000000%	✔
  3	  6	  5	0.0000000000004547	0.0000000000000000	0.0000000000000000%	✔
  3	  6	  6	9304.6153846153865743	9304.6153846153847553	0.0000000000000195%	✔
  3	  6	  7	-0.0000000000002130	0.0000000000000000	0.0000000000000000%	✔
  3	  6	  8	-0.0000000000001705	0.0000000000000000	0.0000000000000000%	✔
  3	  6	  9	-0.0000000000023874	0.0000000000000000	0.0000000000000000%	✔
  3	  7	  3	-0.0000000000000355	0.0000000000000000	0.0000000000000000%	✔
  3	  7	  4	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  7	  5	-0.0000000000000284	0.0000000000000000	0.0000000000000000%	✔
  3	  7	  6	-0.0000000000002130	0.0000000000000000	0.0000000000000000%	✔
  3	  7	  7	20160.0000000000036380	20160.0000000000000000	0.0000000000000180%	✔
  3	  7	  8	0.0000000000002274	0.0000000000000000	0.0000000000000000%	✔
  3	  7	  9	-0.0000000000027285	0.0000000000000000	0.0000000000000000%	✔
  3	  8	  3	0.0000000000000639	0.0000000000000000	0.0000000000000000%	✔
  3	  8	  4	-0.0000000000001990	0.0000000000000000	0.0000000000000000%	✔
  3	  8	  5	-0.0000000000001492	0.0000000000000000	0.0000000000000000%	✔
  3	  8	  6	-0.0000000000001705	0.0000000000000000	0.0000000000000000%	✔
  3	  8	  7	0.0000000000002274	0.0000000000000000	0.0000000000000000%	✔
  3	  8	  8	39134.1176470588252414	39134.1176470588252414	0.0000000000000000%	✔
  3	  8	  9	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  9	  3	0.0000000000000151	0.0000000000000000	0.0000000000000000%	✔
  3	  9	  4	-0.0000000000001137	0.0000000000000000	0.0000000000000000%	✔
  3	  9	  5	-0.0000000000000568	0.0000000000000000	0.0000000000000000%	✔
  3	  9	  6	-0.0000000000023874	0.0000000000000000	0.0000000000000000%	✔
  3	  9	  7	-0.0000000000027285	0.0000000000000000	0.0000000000000000%	✔
  3	  9	  8	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  9	  9	70029.4736842105048709	70029.4736842105339747	0.0000000000000416%	✔
  4	  4	  4	8960.0000000000018190	8960.0000000000000000	0.0000000000000203%	✔
  4	  4	  5	-0.0000000000018190	0.0000000000000000	0.0000000000000000%	✔
  4	  4	  6	-0.0000000000007105	0.0000000000000000	0.0000000000000000%	✔
  4	  4	  7	-0.0000000000002274	0.0000000000000000	0.0000000000000000%	✔
  4	  4	  8	0.0000000000073896	0.0000000000000000	0.0000000000000000%	✔
  4	  4	  9	0.0000000000003411	0.0000000000000000	0.0000000000000000%	✔
  4	  5	  4	-0.0000000000018190	0.0000000000000000	0.0000000000000000%	✔
  4	  5	  5	65978.1818181818380253	65978.1818181818234734	0.0000000000000221%	✔
  4	  5	  6	-0.0000000000009202	0.0000000000000000	0.0000000000000000%	✔
  4	  5	  7	-0.0000000000582077	0.0000000000000000	0.0000000000000000%	✔
  4	  5	  8	-0.0000000000022737	0.0000000000000000	0.0000000000000000%	✔
  4	  5	  9	-0.0000000000072760	0.0000000000000000	0.0000000000000000%	✔
  4	  6	  4	-0.0000000000007105	0.0000000000000000	0.0000000000000000%	✔
  4	  6	  5	-0.0000000000009202	0.0000000000000000	0.0000000000000000%	✔
  4	  6	  6	279138.4615384615026414	279138.4615384615608491	0.0000000000000209%	✔
  4	  6	  7	-0.0000000000182201	0.0000000000000000	0.0000000000000000%	✔
  4	  6	  8	0.0000000000554792	0.0000000000000000	0.0000000000000000%	✔
  4	  6	  9	0.0000000000291038	0.0000000000000000	0.0000000000000000%	✔
  4	  7	  4	-0.0000000000002274	0.0000000000000000	0.0000000000000000%	✔
  4	  7	  5	-0.0000000000582077	0.0000000000000000	0.0000000000000000%	✔
  4	  7	  6	-0.0000000000182201	0.0000000000000000	0.0000000000000000%	✔
  4	  7	  7	887040.0000000000000000	887040.0000000000000000	0.0000000000000000%	✔
  4	  7	  8	0.0000000000309228	0.0000000000000000	0.0000000000000000%	✔
  4	  7	  9	0.0000000001036824	0.0000000000000000	0.0000000000000000%	✔
  4	  8	  4	0.0000000000073896	0.0000000000000000	0.0000000000000000%	✔
  4	  8	  5	-0.0000000000022737	0.0000000000000000	0.0000000000000000%	✔
  4	  8	  6	0.0000000000554792	0.0000000000000000	0.0000000000000000%	✔
  4	  8	  7	0.0000000000309228	0.0000000000000000	0.0000000000000000%	✔
  4	  8	  8	2348047.0588235296308994	2348047.0588235291652381	0.0000000000000198%	✔
  4	  8	  9	-0.0000000000145519	0.0000000000000000	0.0000000000000000%	✔
  4	  9	  4	0.0000000000003411	0.0000000000000000	0.0000000000000000%	✔
  4	  9	  5	-0.0000000000072760	0.0000000000000000	0.0000000000000000%	✔
  4	  9	  6	0.0000000000291038	0.0000000000000000	0.0000000000000000%	✔
  4	  9	  7	0.0000000001036824	0.0000000000000000	0.0000000000000000%	✔
  4	  9	  8	-0.0000000000145519	0.0000000000000000	0.0000000000000000%	✔
  4	  9	  9	5462298.9473684187978506	5462298.9473684215918183	0.0000000000000512%	✔
  5	  5	  5	659781.8181818183511496	659781.8181818182347342	0.0000000000000176%	✔
  5	  5	  6	-0.0000000000018190	0.0000000000000000	0.0000000000000000%	✔
  5	  5	  7	0.0000000002328306	0.0000000000000000	0.0000000000000000%	✔
  5	  5	  8	0.0000000005671836	0.0000000000000000	0.0000000000000000%	✔
  5	  5	  9	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  5	  6	  5	-0.0000000000018190	0.0000000000000000	0.0000000000000000%	✔
  5	  6	  6	6141046.1538461567834020	6141046.1538461539894342	0.0000000000000455%	✔
  5	  6	  7	0.0000000002501110	0.0000000000000000	0.0000000000000000%	✔
  5	  6	  8	0.0000000016298145	0.0000000000000000	0.0000000000000000%	✔
  5	  6	  9	0.0000000009313226	0.0000000000000000	0.0000000000000000%	✔
  5	  7	  5	0.0000000002328306	0.0000000000000000	0.0000000000000000%	✔
  5	  7	  6	0.0000000002501110	0.0000000000000000	0.0000000000000000%	✔
  5	  7	  7	31933440.0000000000000000	31933440.0000000000000000	0.0000000000000000%	✔
  5	  7	  8	0.0000000025029294	0.0000000000000000	0.0000000000000000%	✔
  5	  7	  9	0.0000000037252903	0.0000000000000000	0.0000000000000000%	✔
  5	  8	  5	0.0000000005671836	0.0000000000000000	0.0000000000000000%	✔
  5	  8	  6	0.0000000016298145	0.0000000000000000	0.0000000000000000%	✔
  5	  8	  7	0.0000000025029294	0.0000000000000000	0.0000000000000000%	✔
  5	  8	  8	122098447.0588235259056091	122098447.0588235259056091	0.0000000000000000%	✔
  5	  8	  9	-0.0000000013969839	0.0000000000000000	0.0000000000000000%	✔
  5	  9	  5	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  5	  9	  6	0.0000000009313226	0.0000000000000000	0.0000000000000000%	✔
  5	  9	  7	0.0000000037252903	0.0000000000000000	0.0000000000000000%	✔
  5	  9	  8	-0.0000000013969839	0.0000000000000000	0.0000000000000000%	✔
  5	  9	  9	382360926.3157894611358643	382360926.3157894611358643	0.0000000000000000%	✔
Test Summary:                              | Pass  Total  Time
∫Pᵢᵐ(x)Pⱼᵐ(x)dx = 2(j+m)!/(2j+1)(j-m)! δᵢⱼ |  355    355  0.9s
```

#### Normalization & Orthogonality of $Y_{lm}(\theta,\varphi)$

```math
\int_0^{2\pi}
\int_0^\pi
Y_{lm}(\theta,\varphi)^* Y_{l'm'}(\theta,\varphi) \sin(\theta)
~\mathrm{d}\theta \mathrm{d}\varphi
= \delta_{ll'} \delta_{mm'}
```
```
 l1 l2 m1 m2	numerical	        analyrical        	|error|
  0  0  0  0	1.0000000000000004	1.0000000000000000	0.0000000000000444%	✔
  0  1  0 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0  1  0  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0  1  0  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0  2  0 -2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0  2  0 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0  2  0  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0  2  0  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0  2  0  2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  0 -1  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  0  0  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  0  1  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  1 -1 -1	1.0000000000000002	1.0000000000000000	0.0000000000000222%	✔
  1  1 -1  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  1 -1  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  1  0 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  1  0  0	1.0000000000000002	1.0000000000000000	0.0000000000000222%	✔
  1  1  0  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  1  1 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  1  1  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  1  1  1	1.0000000000000002	1.0000000000000000	0.0000000000000222%	✔
  1  2 -1 -2	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  1  2 -1 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2 -1  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2 -1  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2 -1  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2  0 -2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2  0 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2  0  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2  0  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2  0  2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2  1 -2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2  1 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2  1  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2  1  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1  2  1  2	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2  0 -2  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  0 -1  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  0  0  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  0  1  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  0  2  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1 -2 -1	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2  1 -2  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1 -2  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1 -1 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1 -1  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1 -1  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1  0 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1  0  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1  0  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1  1 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1  1  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1  1  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1  2 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1  2  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  1  2  1	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2  2 -2 -2	1.0000000000000002	1.0000000000000000	0.0000000000000222%	✔
  2  2 -2 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2 -2  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2 -2  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2 -2  2	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2  2 -1 -2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2 -1 -1	1.0000000000000002	1.0000000000000000	0.0000000000000222%	✔
  2  2 -1  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2 -1  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2 -1  2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2  0 -2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2  0 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2  0  0	1.0000000000000002	1.0000000000000000	0.0000000000000222%	✔
  2  2  0  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2  0  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2  1 -2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2  1 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2  1  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2  1  1	1.0000000000000002	1.0000000000000000	0.0000000000000222%	✔
  2  2  1  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2  2 -2	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2  2  2 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2  2  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2  2  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2  2  2  2	1.0000000000000002	1.0000000000000000	0.0000000000000222%	✔
Test Summary:                              | Pass  Total  Time
∫Yₗ₁ₘ₁(θ,φ)Yₗ₂ₘ₂(θ,φ)sinθdθdφ = δₗ₁ₗ₂δₘ₁ₘ₂ |   81     81  1.8s
```

#### Associated Laguerre Polynomials $L_n^{k}(x)$

```math
  \begin{aligned}
  L_n^{k}(x)
    &= \frac{\mathrm{d}^k}{\mathrm{d}x^k} L_n(x) \\
    &= \frac{\mathrm{d}^k}{\mathrm{d}x^k} \frac{1}{n!} \mathrm{e}^x \frac{\mathrm{d}^n}{\mathrm{d}x ^n} \left( \mathrm{e}^{-x} x^n \right) \\
    &= \sum_{m=0}^{n-k} (-1)^{m+k} \frac{n!}{m!(m+k)!(n-m-k)!} x^m \\
    &= (-1)^k L_{n-k}^{(k)}(x)
  \end{aligned}
```

``n=0, k=0:`` ✔
```math
\begin{aligned}
  L_{0}^{0}(x)
   = e^{x} e^{ - x}
  &= 1 \\
  &= 1 \\
  &= 1
\end{aligned}
```

``n=1, k=0:`` ✔
```math
\begin{aligned}
  L_{1}^{0}(x)
   = e^{x} \frac{\mathrm{d}}{\mathrm{d}x} x e^{ - x}
  &= 1 - x \\
  &= 1 - x \\
  &= 1 - x
\end{aligned}
```

``n=1, k=1:`` ✔
```math
\begin{aligned}
  L_{1}^{1}(x)
   = \frac{\mathrm{d}}{\mathrm{d}x} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} x e^{ - x}
  &= -1 \\
  &= -1 \\
  &= -1
\end{aligned}
```

``n=2, k=0:`` ✔
```math
\begin{aligned}
  L_{2}^{0}(x)
   = \frac{1}{2} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{2} e^{ - x}
  &= 1 - 2 x + \frac{1}{2} x^{2} \\
  &= 1 - 2 x + \frac{1}{2} x^{2} \\
  &= 1 - 2 x + \frac{1}{2} x^{2}
\end{aligned}
```

``n=2, k=1:`` ✔
```math
\begin{aligned}
  L_{2}^{1}(x)
   = \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{2} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{2} e^{ - x}
  &= -2 + x \\
  &= -2 + x \\
  &= -2 + x
\end{aligned}
```

``n=2, k=2:`` ✔
```math
\begin{aligned}
  L_{2}^{2}(x)
   = \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{2} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{2} e^{ - x}
  &= 1 \\
  &= 1 \\
  &= 1
\end{aligned}
```

``n=3, k=0:`` ✔
```math
\begin{aligned}
  L_{3}^{0}(x)
   = \frac{1}{6} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{3} e^{ - x}
  &= 1 - \frac{1}{6} x^{3} - 3 x + \frac{3}{2} x^{2} \\
  &= 1 - \frac{1}{6} x^{3} - 3 x + \frac{3}{2} x^{2} \\
  &= 1 - \frac{1}{6} x^{3} - 3 x + \frac{3}{2} x^{2}
\end{aligned}
```

``n=3, k=1:`` ✔
```math
\begin{aligned}
  L_{3}^{1}(x)
   = \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{6} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{3} e^{ - x}
  &= -3 + 3 x - \frac{1}{2} x^{2} \\
  &= -3 + 3 x - \frac{1}{2} x^{2} \\
  &= -3 + 3 x - \frac{1}{2} x^{2}
\end{aligned}
```

``n=3, k=2:`` ✔
```math
\begin{aligned}
  L_{3}^{2}(x)
   = \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{6} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{3} e^{ - x}
  &= 3 - x \\
  &= 3 - x \\
  &= 3 - x
\end{aligned}
```

``n=3, k=3:`` ✔
```math
\begin{aligned}
  L_{3}^{3}(x)
   = \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{6} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{3} e^{ - x}
  &= -1 \\
  &= -1 \\
  &= -1
\end{aligned}
```

``n=4, k=0:`` ✔
```math
\begin{aligned}
  L_{4}^{0}(x)
   = \frac{1}{24} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{4} e^{ - x}
  &= 1 - \frac{2}{3} x^{3} - 4 x + 3 x^{2} + \frac{1}{24} x^{4} \\
  &= 1 - \frac{2}{3} x^{3} - 4 x + 3 x^{2} + \frac{1}{24} x^{4} \\
  &= 1 - \frac{2}{3} x^{3} - 4 x + 3 x^{2} + \frac{1}{24} x^{4}
\end{aligned}
```

``n=4, k=1:`` ✔
```math
\begin{aligned}
  L_{4}^{1}(x)
   = \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{24} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{4} e^{ - x}
  &= -4 + \frac{1}{6} x^{3} + 6 x - 2 x^{2} \\
  &= -4 + \frac{1}{6} x^{3} + 6 x - 2 x^{2} \\
  &= -4 + \frac{1}{6} x^{3} + 6 x - 2 x^{2}
\end{aligned}
```

``n=4, k=2:`` ✔
```math
\begin{aligned}
  L_{4}^{2}(x)
   = \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{24} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{4} e^{ - x}
  &= 6 - 4 x + \frac{1}{2} x^{2} \\
  &= 6 - 4 x + \frac{1}{2} x^{2} \\
  &= 6 - 4 x + \frac{1}{2} x^{2}
\end{aligned}
```

``n=4, k=3:`` ✔
```math
\begin{aligned}
  L_{4}^{3}(x)
   = \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{24} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{4} e^{ - x}
  &= -4 + x \\
  &= -4 + x \\
  &= -4 + x
\end{aligned}
```

``n=4, k=4:`` ✔
```math
\begin{aligned}
  L_{4}^{4}(x)
   = \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{1}{24} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{4} e^{ - x}
  &= 1 \\
  &= 1 \\
  &= 1
\end{aligned}
```

```
Test Summary:                                          | Pass  Total  Time
Lₙᵏ(x) = dᵏ/dxᵏ Lₙ(x); Lₙ(x) = 1/(n!) eˣ dⁿ/dxⁿ e⁻ˣ xⁿ |   15     15  0.5s
```

#### Normalization & Orthogonality of $L_n^{k}(x)$

```math
\int_{0}^{\infty} \mathrm{e}^{-x} x^k L_i^k(x) L_j^k(x) \mathrm{d}x = \frac{i!}{(i-k)!} \delta_{ij}
```

Replace $n+k$ with $n$ for [the definition of Wolfram MathWorld](https://mathworld.wolfram.com/AssociatedLaguerrePolynomial.html).
```
  i	  j	  k	numerical         	analytical        	|error|
  0	  0	  0	1.0000000000000000	1.0000000000000000	0.0000000000000000%	✔
  0	  1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  2	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  0	  3	  0	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  0	  4	  0	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  0	  5	  0	-0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  0	  6	  0	-0.0000000000000011	0.0000000000000000	0.0000000000000000%	✔
  0	  7	  0	0.0000000000000011	0.0000000000000000	0.0000000000000000%	✔
  1	  0	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  1	  0	1.0000000000000211	1.0000000000000000	0.0000000000021094%	✔
  1	  1	  1	0.9999999999999998	1.0000000000000000	0.0000000000000222%	✔
  1	  2	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  2	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  0	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  4	  0	-0.0000000000000006	0.0000000000000000	0.0000000000000000%	✔
  1	  4	  1	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  1	  5	  0	0.0000000000000007	0.0000000000000000	0.0000000000000000%	✔
  1	  5	  1	-0.0000000000000013	0.0000000000000000	0.0000000000000000%	✔
  1	  6	  0	0.0000000000000039	0.0000000000000000	0.0000000000000000%	✔
  1	  6	  1	-0.0000000000000005	0.0000000000000000	0.0000000000000000%	✔
  1	  7	  0	-0.0000000000000041	0.0000000000000000	0.0000000000000000%	✔
  1	  7	  1	0.0000000000000056	0.0000000000000000	0.0000000000000000%	✔
  2	  0	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  1	  0	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2	  1	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  0	0.9999999999999999	1.0000000000000000	0.0000000000000111%	✔
  2	  2	  1	2.0000000000000004	2.0000000000000000	0.0000000000000222%	✔
  2	  2	  2	2.0000000000000204	2.0000000000000000	0.0000000000010214%	✔
  2	  3	  0	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  4	  0	0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  2	  4	  1	-0.0000000000000004	0.0000000000000000	0.0000000000000000%	✔
  2	  4	  2	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  2	  5	  0	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  2	  5	  1	0.0000000000000039	0.0000000000000000	0.0000000000000000%	✔
  2	  5	  2	0.0000000000000007	0.0000000000000000	0.0000000000000000%	✔
  2	  6	  0	-0.0000000000000052	0.0000000000000000	0.0000000000000000%	✔
  2	  6	  1	0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  2	  6	  2	-0.0000000000000015	0.0000000000000000	0.0000000000000000%	✔
  2	  7	  0	0.0000000000000064	0.0000000000000000	0.0000000000000000%	✔
  2	  7	  1	-0.0000000000000164	0.0000000000000000	0.0000000000000000%	✔
  2	  7	  2	0.0000000000000170	0.0000000000000000	0.0000000000000000%	✔
  3	  0	  0	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  1	  0	-0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  3	  1	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  0	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  0	1.0000000000000002	1.0000000000000000	0.0000000000000222%	✔
  3	  3	  1	3.0000000000000000	3.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	6.0000000000000000	6.0000000000000000	0.0000000000000000%	✔
  3	  3	  3	5.9999999999999991	6.0000000000000000	0.0000000000000148%	✔
  3	  4	  0	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  4	  1	0.0000000000000006	0.0000000000000000	0.0000000000000000%	✔
  3	  4	  2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  4	  3	-0.0000000000000006	0.0000000000000000	0.0000000000000000%	✔
  3	  5	  0	-0.0000000000000009	0.0000000000000000	0.0000000000000000%	✔
  3	  5	  1	-0.0000000000000043	0.0000000000000000	0.0000000000000000%	✔
  3	  5	  2	-0.0000000000000044	0.0000000000000000	0.0000000000000000%	✔
  3	  5	  3	0.0000000000000005	0.0000000000000000	0.0000000000000000%	✔
  3	  6	  0	0.0000000000000041	0.0000000000000000	0.0000000000000000%	✔
  3	  6	  1	-0.0000000000000013	0.0000000000000000	0.0000000000000000%	✔
  3	  6	  2	0.0000000000000047	0.0000000000000000	0.0000000000000000%	✔
  3	  6	  3	0.0000000000000080	0.0000000000000000	0.0000000000000000%	✔
  3	  7	  0	-0.0000000000000080	0.0000000000000000	0.0000000000000000%	✔
  3	  7	  1	0.0000000000000175	0.0000000000000000	0.0000000000000000%	✔
  3	  7	  2	-0.0000000000000653	0.0000000000000000	0.0000000000000000%	✔
  3	  7	  3	-0.0000000000000847	0.0000000000000000	0.0000000000000000%	✔
  4	  0	  0	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  4	  1	  0	-0.0000000000000006	0.0000000000000000	0.0000000000000000%	✔
  4	  1	  1	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  4	  2	  0	0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  4	  2	  1	-0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  4	  2	  2	-0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  4	  3	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  4	  3	  1	0.0000000000000006	0.0000000000000000	0.0000000000000000%	✔
  4	  3	  2	0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  4	  3	  3	-0.0000000000000006	0.0000000000000000	0.0000000000000000%	✔
  4	  4	  0	0.9999999999999736	1.0000000000000000	0.0000000000026423%	✔
  4	  4	  1	3.9999999999999982	4.0000000000000000	0.0000000000000444%	✔
  4	  4	  2	12.0000000000000036	12.0000000000000000	0.0000000000000296%	✔
  4	  4	  3	24.0000000000000036	24.0000000000000000	0.0000000000000148%	✔
  4	  4	  4	23.9999999999999964	24.0000000000000000	0.0000000000000148%	✔
  4	  5	  0	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  4	  5	  1	0.0000000000000021	0.0000000000000000	0.0000000000000000%	✔
  4	  5	  2	0.0000000000000032	0.0000000000000000	0.0000000000000000%	✔
  4	  5	  3	0.0000000000000011	0.0000000000000000	0.0000000000000000%	✔
  4	  5	  4	-0.0000000000000020	0.0000000000000000	0.0000000000000000%	✔
  4	  6	  0	-0.0000000000000014	0.0000000000000000	0.0000000000000000%	✔
  4	  6	  1	0.0000000000000009	0.0000000000000000	0.0000000000000000%	✔
  4	  6	  2	-0.0000000000000152	0.0000000000000000	0.0000000000000000%	✔
  4	  6	  3	-0.0000000000000115	0.0000000000000000	0.0000000000000000%	✔
  4	  6	  4	0.0000000000000024	0.0000000000000000	0.0000000000000000%	✔
  4	  7	  0	0.0000000000000061	0.0000000000000000	0.0000000000000000%	✔
  4	  7	  1	-0.0000000000000007	0.0000000000000000	0.0000000000000000%	✔
  4	  7	  2	0.0000000000000797	0.0000000000000000	0.0000000000000000%	✔
  4	  7	  3	0.0000000000002245	0.0000000000000000	0.0000000000000000%	✔
  4	  7	  4	0.0000000000000521	0.0000000000000000	0.0000000000000000%	✔
  5	  0	  0	-0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  5	  1	  0	0.0000000000000006	0.0000000000000000	0.0000000000000000%	✔
  5	  1	  1	-0.0000000000000013	0.0000000000000000	0.0000000000000000%	✔
  5	  2	  0	0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  5	  2	  1	0.0000000000000038	0.0000000000000000	0.0000000000000000%	✔
  5	  2	  2	0.0000000000000007	0.0000000000000000	0.0000000000000000%	✔
  5	  3	  0	-0.0000000000000009	0.0000000000000000	0.0000000000000000%	✔
  5	  3	  1	-0.0000000000000043	0.0000000000000000	0.0000000000000000%	✔
  5	  3	  2	-0.0000000000000032	0.0000000000000000	0.0000000000000000%	✔
  5	  3	  3	0.0000000000000005	0.0000000000000000	0.0000000000000000%	✔
  5	  4	  0	0.0000000000000002	0.0000000000000000	0.0000000000000000%	✔
  5	  4	  1	0.0000000000000020	0.0000000000000000	0.0000000000000000%	✔
  5	  4	  2	0.0000000000000029	0.0000000000000000	0.0000000000000000%	✔
  5	  4	  3	0.0000000000000020	0.0000000000000000	0.0000000000000000%	✔
  5	  4	  4	-0.0000000000000020	0.0000000000000000	0.0000000000000000%	✔
  5	  5	  0	0.9999999999999999	1.0000000000000000	0.0000000000000111%	✔
  5	  5	  1	4.9999999999987566	5.0000000000000000	0.0000000000248690%	✔
  5	  5	  2	19.9999999999995737	20.0000000000000000	0.0000000000021316%	✔
  5	  5	  3	60.0000000000000000	60.0000000000000000	0.0000000000000000%	✔
  5	  5	  4	120.0000000000000000	120.0000000000000000	0.0000000000000000%	✔
  5	  5	  5	119.9999999999999858	120.0000000000000000	0.0000000000000118%	✔
  5	  6	  0	0.0000000000000007	0.0000000000000000	0.0000000000000000%	✔
  5	  6	  1	-0.0000000000000017	0.0000000000000000	0.0000000000000000%	✔
  5	  6	  2	0.0000000000000112	0.0000000000000000	0.0000000000000000%	✔
  5	  6	  3	0.0000000000000193	0.0000000000000000	0.0000000000000000%	✔
  5	  6	  4	0.0000000000000062	0.0000000000000000	0.0000000000000000%	✔
  5	  6	  5	0.0000000000000074	0.0000000000000000	0.0000000000000000%	✔
  5	  7	  0	-0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  5	  7	  1	-0.0000000000000083	0.0000000000000000	0.0000000000000000%	✔
  5	  7	  2	-0.0000000000000351	0.0000000000000000	0.0000000000000000%	✔
  5	  7	  3	-0.0000000000002530	0.0000000000000000	0.0000000000000000%	✔
  5	  7	  4	-0.0000000000001328	0.0000000000000000	0.0000000000000000%	✔
  5	  7	  5	-0.0000000000000220	0.0000000000000000	0.0000000000000000%	✔
  6	  0	  0	-0.0000000000000011	0.0000000000000000	0.0000000000000000%	✔
  6	  1	  0	0.0000000000000039	0.0000000000000000	0.0000000000000000%	✔
  6	  1	  1	-0.0000000000000005	0.0000000000000000	0.0000000000000000%	✔
  6	  2	  0	-0.0000000000000052	0.0000000000000000	0.0000000000000000%	✔
  6	  2	  1	0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  6	  2	  2	-0.0000000000000015	0.0000000000000000	0.0000000000000000%	✔
  6	  3	  0	0.0000000000000041	0.0000000000000000	0.0000000000000000%	✔
  6	  3	  1	-0.0000000000000015	0.0000000000000000	0.0000000000000000%	✔
  6	  3	  2	0.0000000000000041	0.0000000000000000	0.0000000000000000%	✔
  6	  3	  3	0.0000000000000080	0.0000000000000000	0.0000000000000000%	✔
  6	  4	  0	-0.0000000000000014	0.0000000000000000	0.0000000000000000%	✔
  6	  4	  1	0.0000000000000010	0.0000000000000000	0.0000000000000000%	✔
  6	  4	  2	-0.0000000000000152	0.0000000000000000	0.0000000000000000%	✔
  6	  4	  3	-0.0000000000000100	0.0000000000000000	0.0000000000000000%	✔
  6	  4	  4	0.0000000000000024	0.0000000000000000	0.0000000000000000%	✔
  6	  5	  0	0.0000000000000007	0.0000000000000000	0.0000000000000000%	✔
  6	  5	  1	-0.0000000000000017	0.0000000000000000	0.0000000000000000%	✔
  6	  5	  2	0.0000000000000115	0.0000000000000000	0.0000000000000000%	✔
  6	  5	  3	0.0000000000000160	0.0000000000000000	0.0000000000000000%	✔
  6	  5	  4	0.0000000000000062	0.0000000000000000	0.0000000000000000%	✔
  6	  5	  5	0.0000000000000074	0.0000000000000000	0.0000000000000000%	✔
  6	  6	  0	1.0000000000000047	1.0000000000000000	0.0000000000004663%	✔
  6	  6	  1	6.0000000000000124	6.0000000000000000	0.0000000000002072%	✔
  6	  6	  2	29.9999999999999361	30.0000000000000000	0.0000000000002132%	✔
  6	  6	  3	119.9999999999784706	120.0000000000000000	0.0000000000179412%	✔
  6	  6	  4	359.9999999999961346	360.0000000000000000	0.0000000000010737%	✔
  6	  6	  5	720.0000000000001137	720.0000000000000000	0.0000000000000158%	✔
  6	  6	  6	719.9999999999998863	720.0000000000000000	0.0000000000000158%	✔
  6	  7	  0	0.0000000000000012	0.0000000000000000	0.0000000000000000%	✔
  6	  7	  1	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  6	  7	  2	-0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  6	  7	  3	0.0000000000001086	0.0000000000000000	0.0000000000000000%	✔
  6	  7	  4	0.0000000000001137	0.0000000000000000	0.0000000000000000%	✔
  6	  7	  5	0.0000000000000036	0.0000000000000000	0.0000000000000000%	✔
  6	  7	  6	0.0000000000000684	0.0000000000000000	0.0000000000000000%	✔
  7	  0	  0	0.0000000000000011	0.0000000000000000	0.0000000000000000%	✔
  7	  1	  0	-0.0000000000000041	0.0000000000000000	0.0000000000000000%	✔
  7	  1	  1	0.0000000000000056	0.0000000000000000	0.0000000000000000%	✔
  7	  2	  0	0.0000000000000064	0.0000000000000000	0.0000000000000000%	✔
  7	  2	  1	-0.0000000000000163	0.0000000000000000	0.0000000000000000%	✔
  7	  2	  2	0.0000000000000170	0.0000000000000000	0.0000000000000000%	✔
  7	  3	  0	-0.0000000000000079	0.0000000000000000	0.0000000000000000%	✔
  7	  3	  1	0.0000000000000176	0.0000000000000000	0.0000000000000000%	✔
  7	  3	  2	-0.0000000000000652	0.0000000000000000	0.0000000000000000%	✔
  7	  3	  3	-0.0000000000000847	0.0000000000000000	0.0000000000000000%	✔
  7	  4	  0	0.0000000000000061	0.0000000000000000	0.0000000000000000%	✔
  7	  4	  1	-0.0000000000000007	0.0000000000000000	0.0000000000000000%	✔
  7	  4	  2	0.0000000000000793	0.0000000000000000	0.0000000000000000%	✔
  7	  4	  3	0.0000000000002245	0.0000000000000000	0.0000000000000000%	✔
  7	  4	  4	0.0000000000000521	0.0000000000000000	0.0000000000000000%	✔
  7	  5	  0	-0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  7	  5	  1	-0.0000000000000085	0.0000000000000000	0.0000000000000000%	✔
  7	  5	  2	-0.0000000000000354	0.0000000000000000	0.0000000000000000%	✔
  7	  5	  3	-0.0000000000002566	0.0000000000000000	0.0000000000000000%	✔
  7	  5	  4	-0.0000000000001368	0.0000000000000000	0.0000000000000000%	✔
  7	  5	  5	-0.0000000000000220	0.0000000000000000	0.0000000000000000%	✔
  7	  6	  0	0.0000000000000012	0.0000000000000000	0.0000000000000000%	✔
  7	  6	  1	-0.0000000000000003	0.0000000000000000	0.0000000000000000%	✔
  7	  6	  2	-0.0000000000000012	0.0000000000000000	0.0000000000000000%	✔
  7	  6	  3	0.0000000000001121	0.0000000000000000	0.0000000000000000%	✔
  7	  6	  4	0.0000000000001277	0.0000000000000000	0.0000000000000000%	✔
  7	  6	  5	-0.0000000000000675	0.0000000000000000	0.0000000000000000%	✔
  7	  6	  6	0.0000000000000684	0.0000000000000000	0.0000000000000000%	✔
  7	  7	  0	1.0000000000000067	1.0000000000000000	0.0000000000006661%	✔
  7	  7	  1	6.9999999999999885	7.0000000000000000	0.0000000000001649%	✔
  7	  7	  2	42.0000000000000000	42.0000000000000000	0.0000000000000000%	✔
  7	  7	  3	209.9999999999998863	210.0000000000000000	0.0000000000000541%	✔
  7	  7	  4	840.0000000000002274	840.0000000000000000	0.0000000000000271%	✔
  7	  7	  5	2519.9999999997753548	2520.0000000000000000	0.0000000000089145%	✔
  7	  7	  6	5039.9999999999854481	5040.0000000000000000	0.0000000000002887%	✔
  7	  7	  7	5040.0000000000000000	5040.0000000000000000	0.0000000000000000%	✔
Test Summary:                                 | Pass  Total  Time
∫exp(-x)xᵏLᵢᵏ(x)Lⱼᵏ(x)dx = (2i+k)!/(i+k)! δᵢⱼ |  204    204  0.7s
```

#### Normalization of $R_{nl}(r)$

```math
\int |R_{nl}(r)|^2 r^2 \mathrm{d}r = 1
```
```
  n	  l	numerical         	analytical        	|error|
  1	  0	1.0000000000000286	1.0000000000000000	0.0000000000028644%	✔
  2	  0	1.0000000000000002	1.0000000000000000	0.0000000000000222%	✔
  2	  1	1.0000000000000000	1.0000000000000000	0.0000000000000000%	✔
  3	  0	0.9999999999999999	1.0000000000000000	0.0000000000000111%	✔
  3	  1	0.9999999999992634	1.0000000000000000	0.0000000000736633%	✔
  3	  2	0.9999999999998338	1.0000000000000000	0.0000000000166200%	✔
  4	  0	0.9999999999999916	1.0000000000000000	0.0000000000008438%	✔
  4	  1	0.9999999999999950	1.0000000000000000	0.0000000000004996%	✔
  4	  2	0.9999999999999987	1.0000000000000000	0.0000000000001332%	✔
  4	  3	1.0000000000000000	1.0000000000000000	0.0000000000000000%	✔
  5	  0	0.9999999999999996	1.0000000000000000	0.0000000000000444%	✔
  5	  1	0.9999999999999989	1.0000000000000000	0.0000000000001110%	✔
  5	  2	0.9999999999999994	1.0000000000000000	0.0000000000000555%	✔
  5	  3	0.9999999999999999	1.0000000000000000	0.0000000000000111%	✔
  5	  4	1.0000000000000000	1.0000000000000000	0.0000000000000000%	✔
  6	  0	1.0000000000000002	1.0000000000000000	0.0000000000000222%	✔
  6	  1	0.9999999999999999	1.0000000000000000	0.0000000000000111%	✔
  6	  2	0.9999999999999997	1.0000000000000000	0.0000000000000333%	✔
  6	  3	0.9999999999999999	1.0000000000000000	0.0000000000000111%	✔
  6	  4	0.9999999999999998	1.0000000000000000	0.0000000000000222%	✔
  6	  5	0.9999999999999994	1.0000000000000000	0.0000000000000555%	✔
  7	  0	0.9999999999999962	1.0000000000000000	0.0000000000003775%	✔
  7	  1	0.9999999999999997	1.0000000000000000	0.0000000000000333%	✔
  7	  2	0.9999999999999978	1.0000000000000000	0.0000000000002220%	✔
  7	  3	0.9999999999999987	1.0000000000000000	0.0000000000001332%	✔
  7	  4	0.9999999999999992	1.0000000000000000	0.0000000000000777%	✔
  7	  5	1.0000000000000000	1.0000000000000000	0.0000000000000000%	✔
  7	  6	0.9999999999999726	1.0000000000000000	0.0000000000027423%	✔
  8	  0	1.0000000000000082	1.0000000000000000	0.0000000000008216%	✔
  8	  1	0.9999999999999961	1.0000000000000000	0.0000000000003886%	✔
  8	  2	1.0000000000000044	1.0000000000000000	0.0000000000004441%	✔
  8	  3	1.0000000000000002	1.0000000000000000	0.0000000000000222%	✔
  8	  4	1.0000000000000009	1.0000000000000000	0.0000000000000888%	✔
  8	  5	0.9999999999999999	1.0000000000000000	0.0000000000000111%	✔
  8	  6	0.9999999999999996	1.0000000000000000	0.0000000000000444%	✔
  8	  7	0.9999999999999999	1.0000000000000000	0.0000000000000111%	✔
  9	  0	0.9999999999999858	1.0000000000000000	0.0000000000014211%	✔
  9	  1	1.0000000000000036	1.0000000000000000	0.0000000000003553%	✔
  9	  2	1.0000000000000187	1.0000000000000000	0.0000000000018652%	✔
  9	  3	0.9999999999999923	1.0000000000000000	0.0000000000007661%	✔
  9	  4	0.9999999999999903	1.0000000000000000	0.0000000000009659%	✔
  9	  5	0.9999999999999982	1.0000000000000000	0.0000000000001776%	✔
  9	  6	0.9999999999999999	1.0000000000000000	0.0000000000000111%	✔
  9	  7	1.0000000000000007	1.0000000000000000	0.0000000000000666%	✔
  9	  8	0.9999999999999994	1.0000000000000000	0.0000000000000555%	✔
Test Summary:               | Pass  Total  Time
∫|Rₙₗ(r)|²r²dr = δₙ₁ₙ₂δₗ₁ₗ₂ |   45     45  0.6s
```

#### Expected Value of $r$

```math
\langle r \rangle
= \int r |R_{n_1 l_1}(r)|^2 r^2 \mathrm{d}r
= \frac{a_\mu}{2Z} \left[ 3n^2 - l(l+1) \right] \\
a_\mu = a_0 \frac{m_\mathrm{e}}{\mu} \\
\frac{1}{\mu} = \frac{1}{m_\mathrm{e}} + \frac{1}{m_\mathrm{p}}
```

Reference:
- [高柳和夫『朝倉物理学大系 11 原子分子物理学』(2000, 朝倉書店) pp.11-22](https://www.asakura.co.jp/detail.php?book_code=13681)
- [ Quan­tum Me­chan­ics for En­gi­neers by Leon van Dom­me­len](https://web1.eng.famu.fsu.edu/~dommelen/quantum/style_a/nt_rsexp.html)
```
  n	  l	numerical         	analytical        	|error|
  1	  0	1.4999999999999998	1.5000000000000000	0.0000000000000148%	✔
  2	  0	6.0000000000000000	6.0000000000000000	0.0000000000000000%	✔
  2	  1	4.9999999999999991	5.0000000000000000	0.0000000000000178%	✔
  3	  0	13.4999999999999982	13.5000000000000000	0.0000000000000132%	✔
  3	  1	12.5000000000000018	12.5000000000000000	0.0000000000000142%	✔
  3	  2	10.4999999999999982	10.5000000000000000	0.0000000000000169%	✔
  4	  0	23.9999999999989235	24.0000000000000000	0.0000000000044853%	✔
  4	  1	22.9999999999993037	23.0000000000000000	0.0000000000030275%	✔
  4	  2	20.9999999999997513	21.0000000000000000	0.0000000000011842%	✔
  4	  3	17.9999999999999574	18.0000000000000000	0.0000000000002368%	✔
  5	  0	37.4999999999999147	37.5000000000000000	0.0000000000002274%	✔
  5	  1	36.4999999999999716	36.5000000000000000	0.0000000000000779%	✔
  5	  2	34.4999999999999858	34.5000000000000000	0.0000000000000412%	✔
  5	  3	31.4999999999999929	31.5000000000000000	0.0000000000000226%	✔
  5	  4	27.4999999999432916	27.5000000000000000	0.0000000002062124%	✔
  6	  0	54.0000000000009095	54.0000000000000000	0.0000000000016842%	✔
  6	  1	53.0000000000012008	53.0000000000000000	0.0000000000022657%	✔
  6	  2	51.0000000000003268	51.0000000000000000	0.0000000000006409%	✔
  6	  3	48.0000000000001279	48.0000000000000000	0.0000000000002665%	✔
  6	  4	44.0000000000000142	44.0000000000000000	0.0000000000000323%	✔
  6	  5	38.9999999999999858	39.0000000000000000	0.0000000000000364%	✔
  7	  0	73.4999999999998579	73.5000000000000000	0.0000000000001933%	✔
  7	  1	72.5000000000000284	72.5000000000000000	0.0000000000000392%	✔
  7	  2	70.4999999999998437	70.5000000000000000	0.0000000000002217%	✔
  7	  3	67.4999999999999005	67.5000000000000000	0.0000000000001474%	✔
  7	  4	63.4999999999999645	63.5000000000000000	0.0000000000000559%	✔
  7	  5	58.4999999999999858	58.5000000000000000	0.0000000000000243%	✔
  7	  6	52.4999999999920206	52.5000000000000000	0.0000000000151988%	✔
  8	  0	96.0000000000006537	96.0000000000000000	0.0000000000006809%	✔
  8	  1	94.9999999999993179	95.0000000000000000	0.0000000000007180%	✔
  8	  2	93.0000000000000995	93.0000000000000000	0.0000000000001070%	✔
  8	  3	90.0000000000000711	90.0000000000000000	0.0000000000000789%	✔
  8	  4	86.0000000000000568	86.0000000000000000	0.0000000000000661%	✔
  8	  5	81.0000000000000000	81.0000000000000000	0.0000000000000000%	✔
  8	  6	74.9999999999999574	75.0000000000000000	0.0000000000000568%	✔
  8	  7	68.0000000000000000	68.0000000000000000	0.0000000000000000%	✔
  9	  0	121.5000000000011937	121.5000000000000000	0.0000000000009825%	✔
  9	  1	120.5000000000002274	120.5000000000000000	0.0000000000001887%	✔
  9	  2	118.5000000000011653	118.5000000000000000	0.0000000000009834%	✔
  9	  3	115.5000000000000853	115.5000000000000000	0.0000000000000738%	✔
  9	  4	111.4999999999978400	111.5000000000000000	0.0000000000019373%	✔
  9	  5	106.4999999999992895	106.5000000000000000	0.0000000000006672%	✔
  9	  6	100.4999999999998721	100.5000000000000000	0.0000000000001273%	✔
  9	  7	93.5000000000000000	93.5000000000000000	0.0000000000000000%	✔
  9	  8	85.4999999999999716	85.5000000000000000	0.0000000000000332%	✔
Test Summary:                                                    | Pass  Total  Time
∫r|Rₙₗ(r)|²r²dr = (a₀×mₑ/μ)/2Z × [3n²-l(l+1)]; 1/μ = 1/mₑ + 1/mₚ |   45     45  0.6s
```

#### Expected Value of $r^2$

```math
\langle r^2 \rangle
= \int r^2 |R_{n_1 l_1}(r)|^2 r^2 \mathrm{d}r
= \frac{a_\mu^2}{2Z^2} n^2 \left[ 5n^2 + 1 - 3l(l+1) \right] \\
a_\mu = a_0 \frac{m_\mathrm{e}}{\mu} \\
\frac{1}{\mu} = \frac{1}{m_\mathrm{e}} + \frac{1}{m_\mathrm{p}}
```

Reference:
- [高柳和夫『朝倉物理学大系 11 原子分子物理学』(2000, 朝倉書店) pp.11-22](https://www.asakura.co.jp/detail.php?book_code=13681)
- [ Quan­tum Me­chan­ics for En­gi­neers by Leon van Dom­me­len](https://web1.eng.famu.fsu.edu/~dommelen/quantum/style_a/nt_rsexp.html)
```
  n	  l	numerical         	analytical        	|error|
  1	  0	3.0000000000000004	3.0000000000000000	0.0000000000000148%	✔
  2	  0	42.0000000000000000	42.0000000000000000	0.0000000000000000%	✔
  2	  1	30.0000000000000000	30.0000000000000000	0.0000000000000000%	✔
  3	  0	207.0000000000000284	207.0000000000000000	0.0000000000000137%	✔
  3	  1	180.0000000000000000	180.0000000000000000	0.0000000000000000%	✔
  3	  2	125.9999999999999858	126.0000000000000000	0.0000000000000113%	✔
  4	  0	647.9999999999030251	648.0000000000000000	0.0000000000149653%	✔
  4	  1	599.9999999999364491	600.0000000000000000	0.0000000000105918%	✔
  4	  2	503.9999999999748184	504.0000000000000000	0.0000000000049964%	✔
  4	  3	359.9999999999955094	360.0000000000000000	0.0000000000012474%	✔
  5	  0	1574.9999999999988631	1575.0000000000000000	0.0000000000000722%	✔
  5	  1	1499.9999999999977263	1500.0000000000000000	0.0000000000001516%	✔
  5	  2	1349.9999999999995453	1350.0000000000000000	0.0000000000000337%	✔
  5	  3	1125.0000000000029559	1125.0000000000000000	0.0000000000002627%	✔
  5	  4	824.9999999999998863	825.0000000000000000	0.0000000000000138%	✔
  6	  0	3257.9999999999968168	3258.0000000000000000	0.0000000000000977%	✔
  6	  1	3149.9999999999922693	3150.0000000000000000	0.0000000000002454%	✔
  6	  2	2933.9999999999981810	2934.0000000000000000	0.0000000000000620%	✔
  6	  3	2610.0000000000327418	2610.0000000000000000	0.0000000000012545%	✔
  6	  4	2178.0000000000081855	2178.0000000000000000	0.0000000000003758%	✔
  6	  5	1638.0000000000002274	1638.0000000000000000	0.0000000000000139%	✔
  7	  0	6026.9999999999918145	6027.0000000000000000	0.0000000000001358%	✔
  7	  1	5880.0000000000027285	5880.0000000000000000	0.0000000000000464%	✔
  7	  2	5585.9999999999899956	5586.0000000000000000	0.0000000000001791%	✔
  7	  3	5144.9999999999918145	5145.0000000000000000	0.0000000000001591%	✔
  7	  4	4556.9999999999972715	4557.0000000000000000	0.0000000000000599%	✔
  7	  5	3821.9999999999990905	3822.0000000000000000	0.0000000000000238%	✔
  7	  6	2940.0000000000013642	2940.0000000000000000	0.0000000000000464%	✔
  8	  0	10272.0000000000291038	10272.0000000000000000	0.0000000000002833%	✔
  8	  1	10079.9999999999945430	10080.0000000000000000	0.0000000000000541%	✔
  8	  2	9695.9999999999927240	9696.0000000000000000	0.0000000000000750%	✔
  8	  3	9120.0000000000109139	9120.0000000000000000	0.0000000000001197%	✔
  8	  4	8352.0000000000018190	8352.0000000000000000	0.0000000000000218%	✔
  8	  5	7392.0000000000100044	7392.0000000000000000	0.0000000000001353%	✔
  8	  6	6240.0000000000000000	6240.0000000000000000	0.0000000000000000%	✔
  8	  7	4896.0000000000081855	4896.0000000000000000	0.0000000000001672%	✔
  9	  0	16443.0000000001018634	16443.0000000000000000	0.0000000000006195%	✔
  9	  1	16200.0000000000400178	16200.0000000000000000	0.0000000000002470%	✔
  9	  2	15714.0000000001491571	15714.0000000000000000	0.0000000000009492%	✔
  9	  3	14984.9999999999181455	14985.0000000000000000	0.0000000000005462%	✔
  9	  4	14012.9999999995452526	14013.0000000000000000	0.0000000000032452%	✔
  9	  5	12797.9999999998071871	12798.0000000000000000	0.0000000000015066%	✔
  9	  6	11339.9999999999454303	11340.0000000000000000	0.0000000000004812%	✔
  9	  7	9638.9999999999909051	9639.0000000000000000	0.0000000000000944%	✔
  9	  8	7694.9999999999981810	7695.0000000000000000	0.0000000000000236%	✔
Test Summary:                                                            | Pass  Total  Time
∫r²|Rₙₗ(r)|²r²dr = (a₀×mₑ/μ)²/2Z² × n²[5n²+1-3l(l+1)]; 1/μ = 1/mₑ + 1/mₚ |   45     45  0.6s
```

#### Virial Theorem

The virial theorem $2\langle T \rangle + \langle V \rangle = 0$ and the definition of Hamiltonian $\langle H \rangle = \langle T \rangle + \langle V \rangle$ derive $\langle H \rangle = \frac{1}{2} \langle V \rangle$ and $\langle H \rangle = -\langle T \rangle$.

```math
\frac{1}{2} \int \psi_n^\ast(x) V(x) \psi_n(x) \mathrm{d}x = E_n
```
```
  n	numerical         	analytical        	|error|
  1	-0.9999999999999999	-1.0000000000000000	0.0000000000000111%	✔
  2	-0.2500000000000001	-0.2500000000000000	0.0000000000000444%	✔
  3	-0.1111111111111111	-0.1111111111111111	0.0000000000000125%	✔
  4	-0.0625000000000000	-0.0625000000000000	0.0000000000000222%	✔
  5	-0.0400000000000000	-0.0400000000000000	0.0000000000000520%	✔
  6	-0.0277777777777777	-0.0277777777777778	0.0000000000003497%	✔
  7	-0.0204081632653061	-0.0204081632653061	0.0000000000003400%	✔
  8	-0.0156250000000002	-0.0156250000000000	0.0000000000011102%	✔
  9	-0.0123456790123456	-0.0123456790123457	0.0000000000002389%	✔
 10	-0.0100000000000004	-0.0100000000000000	0.0000000000036256%	✔
Test Summary:      | Pass  Total  Time
<ψₙ|V|ψₙ> / 2 = Eₙ |   10     10  0.5s
```

#### Normalization & Orthogonality of $\psi_n(r,\theta,\varphi)$

```math
\int \psi_i^\ast(r,\theta,\varphi) \psi_j(r,\theta,\varphi) r^2 \mathrm{d}r \mathrm{d}\theta \mathrm{d}\varphi = \delta_{ij}
```
```
 n1	 n2	 l1	 l2	 m1	 m2	numerical         	analytical        	|error|
  1	  1	  0	  0	  0	  0	1.0000000002519327	1.0000000000000000	0.0000000251932697%	✔
  1	  2	  0	  0	  0	  0	-0.0000000112226007	0.0000000000000000	0.0000000000000000%	✔
  1	  2	  0	  1	  0	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  2	  0	  1	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  2	  0	  1	  0	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  0	  0	  0	  0	-0.0000000456607854	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  0	  1	  0	 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  0	  1	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  0	  1	  0	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  0	  2	  0	 -2	0.0000000000000040	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  0	  2	  0	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  0	  2	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  0	  2	  0	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  1	  3	  0	  2	  0	  2	0.0000000000000040	0.0000000000000000	0.0000000000000000%	✔
  2	  1	  0	  0	  0	  0	-0.0000000112226007	0.0000000000000000	0.0000000000000000%	✔
  2	  1	  1	  0	 -1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  1	  1	  0	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  1	  1	  0	  1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  0	  0	  0	  0	1.0000069705173094	1.0000000000000000	0.0006970517309357%	✔
  2	  2	  0	  1	  0	 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  0	  1	  0	  0	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  0	  1	  0	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  1	  0	 -1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  1	  0	  0	  0	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  1	  0	  1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  1	  1	 -1	 -1	1.0000023013514421	1.0000000000000000	0.0002301351442080%	✔
  2	  2	  1	  1	 -1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  1	  1	 -1	  1	-0.0000000000000429	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  1	  1	  0	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  1	  1	  0	  0	1.0000023013514421	1.0000000000000000	0.0002301351442080%	✔
  2	  2	  1	  1	  0	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  1	  1	  1	 -1	-0.0000000000000429	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  1	  1	  1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  2	  1	  1	  1	  1	1.0000023013514421	1.0000000000000000	0.0002301351442080%	✔
  2	  3	  0	  0	  0	  0	0.0000885194208975	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  0	  1	  0	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  0	  1	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  0	  1	  0	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  0	  2	  0	 -2	-0.0000000000000299	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  0	  2	  0	 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  0	  2	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  0	  2	  0	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  0	  2	  0	  2	-0.0000000000000299	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  0	 -1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  0	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  0	  1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  1	 -1	 -1	0.0000387303383981	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  1	 -1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  1	 -1	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  1	  0	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  1	  0	  0	0.0000387303383981	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  1	  0	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  1	  1	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  1	  1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  1	  1	  1	0.0000387303383981	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	 -1	 -2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	 -1	 -1	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	 -1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	 -1	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	 -1	  2	-0.0000000002724723	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	  0	 -2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	  0	 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	  0	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	  0	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	  1	 -2	0.0000000002724723	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	  1	 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	  1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	  1	  1	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  2	  3	  1	  2	  1	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  1	  0	  0	  0	  0	-0.0000000456607854	0.0000000000000000	0.0000000000000000%	✔
  3	  1	  1	  0	 -1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  1	  1	  0	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  1	  1	  0	  1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  1	  2	  0	 -2	  0	0.0000000000000040	0.0000000000000000	0.0000000000000000%	✔
  3	  1	  2	  0	 -1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  1	  2	  0	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  1	  2	  0	  1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  1	  2	  0	  2	  0	0.0000000000000040	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  0	  0	  0	  0	0.0000885194208975	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  0	  1	  0	 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  0	  1	  0	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  0	  1	  0	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	  0	 -1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	  0	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	  0	  1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	  1	 -1	 -1	0.0000387303383981	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	  1	 -1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	  1	 -1	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	  1	  0	 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	  1	  0	  0	0.0000387303383981	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	  1	  0	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	  1	  1	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	  1	  1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  1	  1	  1	  1	0.0000387303383981	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  0	 -2	  0	-0.0000000000000299	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  0	 -1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  0	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  0	  1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  0	  2	  0	-0.0000000000000299	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	 -2	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	 -2	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	 -2	  1	0.0000000002724723	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	 -1	 -1	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	 -1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	 -1	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	  0	 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	  0	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	  0	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	  1	 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	  1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	  1	  1	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	  2	 -1	-0.0000000002724723	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	  2	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  2	  2	  1	  2	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  0	  0	  0	  0	1.0020525945042456	1.0000000000000000	0.2052594504245553%	✔
  3	  3	  0	  1	  0	 -1	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  0	  1	  0	  0	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  0	  1	  0	  1	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  0	  2	  0	 -2	0.0000000000000248	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  0	  2	  0	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  0	  2	  0	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  0	  2	  0	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  0	  2	  0	  2	0.0000000000000248	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  0	 -1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  0	  0	  0	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  0	  1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  1	 -1	 -1	1.0012233463884983	1.0000000000000000	0.1223346388498303%	✔
  3	  3	  1	  1	 -1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  1	 -1	  1	-0.0000000000000430	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  1	  0	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  1	  0	  0	1.0012233463884981	1.0000000000000000	0.1223346388498081%	✔
  3	  3	  1	  1	  0	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  1	  1	 -1	-0.0000000000000430	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  1	  1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  1	  1	  1	1.0012233463884983	1.0000000000000000	0.1223346388498303%	✔
  3	  3	  1	  2	 -1	 -2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	 -1	 -1	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	 -1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	 -1	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	 -1	  2	0.0000000003082355	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	  0	 -2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	  0	 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	  0	  1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	  0	  2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	  1	 -2	-0.0000000003082355	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	  1	 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	  1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	  1	  1	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  1	  2	  1	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  0	 -2	  0	0.0000000000000248	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  0	 -1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  0	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  0	  1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  0	  2	  0	0.0000000000000248	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	 -2	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	 -2	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	 -2	  1	-0.0000000003082355	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	 -1	 -1	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	 -1	  0	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	 -1	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	  0	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	  0	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	  0	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	  1	 -1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	  1	  0	-0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	  1	  1	0.0000000000000001	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	  2	 -1	0.0000000003082355	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	  2	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  1	  2	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	 -2	 -2	1.0003006285656155	1.0000000000000000	0.0300628565615524%	✔
  3	  3	  2	  2	 -2	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	 -2	  0	-0.0000000000000175	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	 -2	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	 -2	  2	0.0000001937793434	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	 -1	 -2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	 -1	 -1	1.0003006285590699	1.0000000000000000	0.0300628559069871%	✔
  3	  3	  2	  2	 -1	  0	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	 -1	  1	-0.0000000000000429	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	 -1	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  0	 -2	-0.0000000000000175	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  0	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  0	  0	1.0003006285721614	1.0000000000000000	0.0300628572161399%	✔
  3	  3	  2	  2	  0	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  0	  2	-0.0000000000000175	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  1	 -2	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  1	 -1	-0.0000000000000429	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  1	  0	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  1	  1	1.0003006285590699	1.0000000000000000	0.0300628559069871%	✔
  3	  3	  2	  2	  1	  2	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  2	 -2	0.0000001937793434	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  2	 -1	-0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  2	  0	-0.0000000000000175	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  2	  1	0.0000000000000000	0.0000000000000000	0.0000000000000000%	✔
  3	  3	  2	  2	  2	  2	1.0003006285656155	1.0000000000000000	0.0300628565615524%	✔
Test Summary:                       | Pass  Total  Time
<ψₙ₁ₗ₁ₘ₁|ψₙ₂ₗ₂ₘ₂> = δₙ₁ₙ₂δₗ₁ₗ₂δₘ₁ₘ₂ |  196    196  5.1s

```
